;;; -*- lisp -*-

;; ASDF system definition for loading the Swank server independently
;; of Emacs.
;;
;; This is only useful if you want to start a Swank server in a Lisp
;; processes that doesn't run under Emacs. Lisp processes created by
;; `M-x slime' automatically start the server.

;; Usage:
;;
;;   (require :swank)
;;   (swank:create-swank-server PORT) => ACTUAL-PORT
;;
;; (PORT can be zero to mean "any available port".)
;; Then the Swank server is running on localhost:ACTUAL-PORT. You can
;; use `M-x slime-connect' to connect Emacs to it.
;;
;; This code has been placed in the Public Domain.  All warranties
;; are disclaimed.

(defpackage swank-system
  (:use #:cl #:asdf))

(in-package :swank-system)

(defsystem swank
  :serial t
  :components ((:file "swank-backend")
               (:file "nregex")
               #+(or cmu sbcl scl) (:file "swank-source-path-parser")
               #+(or cmu sbcl scl) (:file "swank-source-file-cache")
               #+clisp (:file "xref")
               #+(or clisp opencml) (:file "metering")
               (:file #+allegro "swank-allegro"
                      #+armedbear "swank-abcl"
                      #+clisp "swank-clisp"
                      #+cmu "swank-cmucl"
                      #+cormanlisp "swank-corman"
                      #+ecl "swank-ecl"
                      #+lispworks "swank-lispworks"
                      #+openmcl "swank-openmcl"
                      #+sbcl "swank-sbcl"
                      #+scl "swank-scl")
               #+(or allegro clisp cormanlisp ecl lispworks openmcl sbcl)
               (:file "swank-gray")
               (:file "swank")))

(defun load-init-file (name directory)
  (load (make-pathname :name name :type "lisp" :defaults directory)
        :if-does-not-exist nil))

(defmethod perform :after ((op load-op) (c (eql (find-system :swank))))
  (funcall (intern (string :warn-unimplemented-interfaces) :swank-backend))
  (load-init-file "site-init" (component-pathname c))
  (load-init-file ".swank" (user-homedir-pathname)))
